@@ -32,13 +32,13 @@ class KGamma: public KCModule
    Q_OBJECT
    public:
       KGamma(QWidget* parent_P, const QVariantList &args );
-      virtual ~KGamma();
+      ~KGamma() override;
 
-      void load() Q_DECL_OVERRIDE;
-      void save() Q_DECL_OVERRIDE;
-      void defaults() Q_DECL_OVERRIDE;
+      void load() override;
+      void save() override;
+      void defaults() override;
       int buttons();
-      QString quickHelp() const Q_DECL_OVERRIDE;
+      QString quickHelp() const override;
 
     protected: // Protected methods
       /** The user interface */
